@@ -52,6 +52,13 @@ char * CHARTRUE = "true";
  
 extern struct extendedOptions * optionsArray;
 static int g_logger_sigterm = 0;
+
+#define SWC_SHELL_KEY_SH	SH_A_sh
+#define SWC_SHELL_KEY_KSH	SH_A_ksh
+#define SWC_SHELL_KEY_MKSH	SH_A_mksh
+#define SWC_SHELL_KEY_BASH	SH_A_bash
+#define SWC_SHELL_KEY_POSIX	"posix"
+#define SWC_SHELL_KEY_DETECT	"detect"
 	
 static
 ssize_t
@@ -507,8 +514,6 @@ determine_longest_common_dir(STRAR * p_sourcepath_list)
 {
 	char * s;
 	char * dirname;
-	char * dir2;
-	char * base;
 	int is_same;
 	int nf;
 	int n;
@@ -714,7 +719,7 @@ void
 swc_copyright_info(FILE * fp)
 {
 	fprintf(fp,  "%s",
-"Copyright (C) 2004,2005,2006,2007 Jim Lowe\n"
+"Copyright (C) 2004,2005,2006,2007,2008,2009,2010 Jim Lowe\n"
 "Portions are copyright 1985-2000 Free Software Foundation, Inc.\n"
 "This software is distributed under the terms of the GNU General Public License\n"
 "and comes with NO WARRANTY to the extent permitted by law.\n"
@@ -888,6 +893,25 @@ swc_form_command_args(GB * G,
 	return 0;
 }
 
+char *
+swc_make_absolute_path(char * target_current_dir, char * target_path)
+{
+	char * ret;
+	STROB * tmp;
+
+	if (*target_path == '/')
+		return target_path;
+
+	tmp = strob_open(32);
+	strob_strcpy(tmp, target_current_dir);
+	strob_strcat(tmp, "/");
+	strob_strcat(tmp, target_path);
+
+	ret = strdup(strob_str(tmp));	
+	strob_close(tmp);
+	return ret;
+}
+
 char *
 swc_validate_targetpath(int nhops, char * targetpath, char * default_target, char * cwd, char * context)
 {
@@ -1761,25 +1785,46 @@ swc_get_pax_read_command(struct g_pax_read_command g_pax_read_commands[],
 			char * keyid, int verbose_level,
 			int keep, char * paxdefault)
 {
-	int i = 0;
+	int i;
 	char * id;
+	char * ret;
 	struct g_pax_read_command * readcmd;
 	
-	if (! keyid) return NULL;
-
-	if (strlen(keyid) == 0) {
-		return swc_get_pax_read_command(
-				g_pax_read_commands,
-				DEFAULT_PAX_R, 
-				verbose_level, keep, DEFAULT_PAX_R);
+	E_DEBUG2("BEGIN struct=%p", (void*)g_pax_read_commands);
+	E_DEBUG2("BEGIN keyid=%s", keyid);
+	E_DEBUG2("BEGIN verbose_level=%d", verbose_level);
+	E_DEBUG2("BEGIN keep=%d", keep);
+	E_DEBUG2("BEGIN paxdefault=%s", paxdefault);
+	if (! keyid) {
+		return NULL;
 	}
+
+	if (keyid == NULL || strlen(keyid) == 0) {
+		E_DEBUG("strlen(keyid) == 0");
+		keyid = DEFAULT_PAX_R;
+	}
+	i = 0;
 	readcmd = &(g_pax_read_commands[i]);
 	id = readcmd->idM;
 	while (id) {
+		E_DEBUG("while..");
 		if (strcmp(keyid, id) == 0) {
-			if (keep) return readcmd->keep_commandM;
-			if (verbose_level <= 0) return readcmd->commandM;
-			return readcmd->verbose_commandM;
+			E_DEBUG("strcmp(keyid, id) == 0");
+			ret = NULL;
+			if (keep) {
+				E_DEBUG("");
+				ret = readcmd->keep_commandM;
+			}
+			if (ret == NULL && verbose_level <= 0) {
+				E_DEBUG("");
+				ret = readcmd->commandM;
+			}
+			if (ret == NULL) {
+				E_DEBUG("");
+				ret = readcmd->verbose_commandM;
+			}
+			E_DEBUG2("return pax command [%s]", ret);
+			return ret;
 		}
 		i++;
 		readcmd = &(g_pax_read_commands[i]);
@@ -1901,7 +1946,6 @@ swc_write_source_copy_script(GB * G,
 	char * blocksize
 	)
 {
-	int n;
 	int ret;
 	int n_source_specs;
 	char * dirname;
@@ -2188,6 +2232,31 @@ swc_write_source_copy_script(GB * G,
 	return !(ret > 0);
 }
 
+int
+swc_read_target_message_129(GB * G, int fd, STROB * cdir, 
+				int vlevel, char * loc)
+{
+	int ret;
+	STROB * control_message;	
+	char * tag;
+	char * d;
+	
+	tag = SWBIS_TARGET_CTL_MSG_129 ": ";
+	control_message = strob_open(32);	
+	strob_strcpy(cdir, "");
+	ret = swc_read_target_ctl_message(G, fd, control_message, vlevel, loc);
+	if (ret < 0) return -1;
+
+	if (strstr(strob_str(control_message), tag) == NULL)
+		return -1;
+
+	d = strob_str(control_message) + strlen(tag);
+	strob_strcpy(cdir, d);
+	swlib_squash_all_trailing_vnewline(strob_str(cdir));
+	strob_close(control_message);
+	return 0;
+}
+
 int
 swc_read_target_ctl_message(GB * G, int fd, STROB * control_message, 
 				int vlevel, char * loc)
@@ -2906,6 +2975,7 @@ swc_check_shell_command_key(GB * G, char * cmd)
 		strcmp(wopt_shell_command, SWC_SHELL_KEY_BASH) &&
 		strcmp(wopt_shell_command, SWC_SHELL_KEY_SH) &&
 		strcmp(wopt_shell_command, SWC_SHELL_KEY_KSH) &&
+		strcmp(wopt_shell_command, SWC_SHELL_KEY_MKSH) &&
 		strcmp(wopt_shell_command, SWC_SHELL_KEY_DETECT) &&
 		strcmp(wopt_shell_command, SWC_SHELL_KEY_POSIX)
 	) {
