@@ -36,52 +36,5 @@
 #include "swlist_lib.h"
 #include "globalblob.h"
 
-struct blist_level blist_levels_i[] = {
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_FILE,
-		"file"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_CONTROL_FILE,
-		"control_file"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_FILESET,
-		"fileset"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_PRODUCT,
-		"product"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_BUNDLE,
-		"bundle"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_SUBPRODUCT,
-		"subproduct"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_DISTRIBUTION,
-		"distribution"
-	},
-	{
-		0, /* is set*/  
-		SW_LEVEL_V_HOST,
-		"host"
-	},
-	{
-		0,
-		0,
-		(char*)NULL
-	}
-};
 
 #endif
