@@ -263,7 +263,7 @@ looper_locked_region(STROB * buf, int vlv)
 
 		"				shls_bashin2 \"" SWBIS_TS_post_verify "\"\n"
 		"				sw_retval=$?\n"
-		"				case $sw_retval in 0) $sh_dash_s;; *) shls_false_;; esac\n"
+		"				case $sw_retval in 0) $sh_dash_s;; *) sleep 2; shls_false_;; esac\n"
 		"				sw_retval=$?\n"
 		"				swexec_status=$sw_retval\n"
 
@@ -1403,6 +1403,12 @@ swverify_write_source_copy_script2(GB * G,
 		"case $sw_retval in 0) $sh_dash_s;; *) shls_false_;; esac\n"
 		"sw_retval=$?\n"
 		"swexec_status=$sw_retval\n"
+		
+		"shls_bashin2 \"" SWBIS_TS_Do_nothing "\"\n"
+		"sw_retval=$?\n"
+		"case $sw_retval in 0) $sh_dash_s;; *) shls_false_;; esac\n"
+		"sw_retval=$?\n"
+		"swexec_status=$sw_retval\n"
 
 		/* Loop over the selections */
 		"		shls_looper \"$sw_retval\"\n"
@@ -1579,8 +1585,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 
 	/* fprintf(stderr, "ENTRY: [%s]\n", catalog_entry_directory); */
 
-	E_DEBUG2("servicing looper: writing: [%s]", strob_str(btmp));
 	strob_sprintf(btmp, 0, "%s\n", catalog_entry_directory);
+	/* swlib_squash_trailing_vnewline(strob_str(btmp));	 */
+	E_DEBUG2("servicing looper: writing: [%s]", strob_str(btmp));
 
 	/* write the catalog entry directory which becomes arg1 to
 	   the shls_looper_payload() routine */
@@ -1661,10 +1668,10 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 
 	e = swicat_e_create();
 	ret = swicat_e_open_entry_tarball(e, ifd);
-	if (ret < 0) {
+	if (ret != 0) {
 		sw_e_msg(G, "error opening catalog entry tarball, ret=%d\n", ret);
 		rstatus = 1;
-		retval = -1;  /* protocol internal error */
+		retval = -2;  /* protocol internal error */
 		looper_abort(G, swicol, ofd);
 		goto error_out;
 	}
@@ -1688,7 +1695,7 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	ret = swicat_e_reset_fd(e);
 	if (ret < 0) {
 		rstatus = 2;
-		retval = -1;
+		retval = -3;
 		sw_e_msg(G, "error reseting swicat_e object, ret=%d\n", ret);
 		looper_abort(G, swicol, ofd);
 		goto error_out;
@@ -1699,19 +1706,26 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	if (G->devel_verboseM)
 		SWLIB_INFO2("NOPEN=%d", uxfio_uxfio_get_nopen());
 
+	E_DEBUG("");
 	swgpg = swgpg_create();
 	if (G->devel_verboseM)
 		SWLIB_INFO2("NOPEN=%d", uxfio_uxfio_get_nopen());
 
+	E_DEBUG("");
 	ret = 0;	
-	if (sig_level >= 0)
+	if (sig_level >= 0) {
+		E_DEBUG("");
 		ret = swicat_e_verify_gpg_signature(e, swgpg);
+		E_DEBUG("");
+	}
+	
 	if (ret != 0) {
 		rstatus = 3;
 		retval = 0;
 		sw_e_msg(G, "error from swicat_e_verify_gpg_signature, ret=%d\n", ret);
 	}
 
+	E_DEBUG("");
 	/* Now interpret the verification results according to extended option
 	   requirements */
 
@@ -1776,10 +1790,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	ret = swpl_report_status(swicol, ofd, G->g_swi_event_fd);
 	*p_rp_status = ret;
 	if (ret) {
-		/* looper_abort(G, swicol, ofd); */
 		rstatus = 6;
-		retval = 0;
-		do_skip_entry = 1;
+		retval = -4;
+		goto error_out;
 	}
 	if (G->g_do_debug_events)
 		swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
@@ -1789,7 +1802,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	ret = swicol_rpsh_wait_cts(swicol, G->g_swi_event_fd);
 	*p_rp_status = ret;
 	if (ret) {
-		looper_abort(G, swicol, ofd);
+		rstatus = -6;
+		retval = -5;
+		goto error_out;
 	}
 
 	E_DEBUG("");
@@ -1806,11 +1821,7 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	if (swi && file_list == NULL) {
 		rstatus = 7;
 		retval = 0;
-		do_skip_entry = 1;
-		/* 
-		looper_abort(G, swicol, ofd);
 		goto error_out;
-		*/
 	}
 	
 	E_DEBUG("");
@@ -1840,9 +1851,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			retval = -5;
+			rstatus = -8;
 			goto error_out;
-			retval = -1;
 		}
 	} else {
 		ret = swpl_unpack_catalog_tarfile(G, swi, ofd,
@@ -1851,9 +1862,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			0 /*alt_catalog_root*/,
 			G->g_swi_event_fd);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			retval = -5;
+			rstatus = -8;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1868,20 +1879,21 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			retval = -6;
+			rstatus = -9;
 			goto error_out;
-			retval = -1;
 		}
 	} else {
 		if (1 && 0) {
+			/* dead code, for testing */
 			ret = swpl_send_nothing_and_wait(swicol, ofd, G->g_swi_event_fd,
        		                SWBIS_TS_retrieve_files_archive,
 				SWICOL_TL_8,
 				SW_SUCCESS);
 			if (ret != 0) {
-				looper_abort(G, swicol, ofd);
+				rstatus = -8;
+				retval = -6;
 				goto error_out;
-				retval = -1;
 			}
 		} else {
 			E_DEBUG("");
@@ -1894,9 +1906,8 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 					pax_write_command_key, -1, -1, (FILE_DIGS*)NULL);
 			E_DEBUG("");
 			if (ret < 0) {
-				rstatus = 8;
-				retval = -1;
-				looper_abort(G, swicol, ofd);
+				rstatus = -10;
+				retval = -11;
 				goto error_out;
 			} else if (ret > 0) {
 				if (ret == SWP_RP_STATUS_NO_GNU_TAR) {
@@ -1963,9 +1974,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -11;
+			retval = -12;
 			goto error_out;
-			retval = -1;
 		}
         } else {
                 /* TS_Catalog_dir_remove */
@@ -1975,9 +1986,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			0 /*alt_catalog_root*/,
 			G->g_swi_event_fd);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -12;
+			retval = -13;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1993,9 +2004,9 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -13;
+			retval = -14;
 			goto error_out;
-			retval = -1;
 		}
         } else {
 		ret = swpl_load_single_status_value (G, swi, ofd, G->g_swi_event_fd,
