@@ -20,12 +20,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
-#include "swuser_config.h"
 #include "swdefinition.h"
 #include "swdefinitionfile.h"
 #include "swexproduct.h"
 #include "swptrlist.h"
-// #include "swptrlist_debug.cxx"
 
 extern "C" {
 #include "uxfio.h"
@@ -38,24 +36,7 @@ extern "C" {
 #include "ahs.h"
 }
 
-//static STROB * sbuf = NULL;
-
-
-/* ***********************
-	int debugM;
-	int mediaTypeM;				// Serial or directory.
-	STROB * controlPathM;			// The control Path, including control directory.
-	STROB * parentPathM;			// The parent path, everything above the control directory.
-	STROB * controlDirectoryM;		// The control directory pathname component.
-
-	swPathName 	*	swpathM;
-	swDefinition 	* 	refererM;	// The definition in the global INDEX that refers to this object.
-  	static swExStruct * 	lastM;
- **************************/
-
-
 char * swExProduct::dump_string_s(char * prefix)
 {
 	return swExCat::dump_string_s(prefix);
 }
-
