@@ -64,16 +64,18 @@ extern "C" {
 
 #define INFO_SIZE_BLANK	"\040\040\040\040\040\040\040\040"  // Eight (8) Spaces
 
+/*
 #ifdef FILENEEDDEBUG
 #define E_DEBUG(format) SWBISERROR("DEBUG", format)
 #define E_DEBUG2(format, arg) SWBISERROR2("DEBUG", format, arg)
 #define E_DEBUG3(format, arg, arg1) \
- 			SWBISERROR3("DEBUG", format, arg, arg1)
+			SWBISERROR3("DEBUG", format, arg, arg1)
 #else
 #define E_DEBUG(format)
 #define E_DEBUG2(format, arg)
 #define E_DEBUG3(format, arg, arg1)
 #endif
+*/
 
 class swObjFiles;
 class swObjFiles_i:  public swExStruct_i
@@ -1772,8 +1774,10 @@ class swObjFiles_i:  public swExStruct_i
 		STROB * tmp;
 		//struct stat st;
 		swPackageFile * archiver;
+		char * old_stat;
 		char * source;
 
+		old_stat = swvarfs_get_stat_syscall(getSwvarfs());
 		swvarfs_set_stat_syscall(getSwvarfs(), "stat");
 		archiver = getArchiver();
 		tmp = strob_open(10);
@@ -1882,7 +1886,7 @@ class swObjFiles_i:  public swExStruct_i
 				// Hack, Release the fd, but keep the data. 
 		swattfile->swfile_re_close_public_image_fd();
 		
-		swvarfs_set_stat_syscall(getSwvarfs(), "lstat");
+		swvarfs_set_stat_syscall(getSwvarfs(), old_stat);
 		strob_close(tmp);
 		return 0;
 	}
