@@ -138,6 +138,7 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 	int level = swdef->get_level();
 	char * umask_value;
 	char * value;
+	char * set_type;
 	int i;
 
 	SWPACKAGEFILE_DEBUG("ENTERING");
@@ -190,6 +191,57 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 	if (xFormat_u_lstat(source, &st) != 0) {
 		return -9991;
 	}
+	
+	swmd = swdef->findAttribute("type");
+
+	// JL if (swmd) swmd->write_fd(2);
+	// fprintf(stderr, "JL fileArrayWasSet[typeE] is [%d]\n", fileArrayWasSet[typeE]);
+	// fprintf(stderr, "JL swmd is %p\n", swmd);
+
+	if (swmd) {
+		//
+		// Here the user explicitly set a type 
+		// we will respect it for the case of a symlink
+		// wrt the follow_symlinks extended option.
+		//
+
+		XFORMAT * xformat;
+		SWVARFS * swvarfs;
+		char * current_stat;
+		char itype;
+		
+		SWPACKAGEFILE_DEBUG("type attribute was set");
+		xformat = xFormat_get_xformat();
+		swvarfs = xformat_get_swvarfs(xformat);
+		current_stat = swvarfs_get_stat_syscall(swvarfs);
+
+		set_type = swmd->get_value((int*)(NULL));
+		if (set_type == NULL) return -9992;
+
+		if (
+			S_ISLNK(st.st_mode) && strcmp(current_stat, SWVARFS_VSTAT_LSTAT) == 0
+		) {
+			//
+			// The source is a symlink and the current stat function is lstat
+			// re-stat with stat()
+			//
+			SWPACKAGEFILE_DEBUG("re-stating -- running stat");
+			swvarfs_set_stat_syscall(swvarfs, SWVARFS_VSTAT_STAT);
+			if (xFormat_u_lstat(source, &st) != 0) {
+				return -9992;
+			}
+			swvarfs_set_stat_syscall(swvarfs, current_stat);
+			itype = getFileTypeFromMode(st.st_mode);
+			if (*set_type != itype) {
+				//
+				// the actual file contradicts the
+				// type set in the PSF.  Let this be an error
+				//
+				fprintf(stderr, "swPackageFile::file type attribute in PSF does not match source.\n");
+				return -1;
+			}
+		}
+	}
 
 	if (umask_value) {
 		SWPACKAGEFILE_DEBUG("");
