@@ -11,6 +11,9 @@
 #include <errno.h>
 #include "swlib.h"
 
+#define DO_APPEND 1
+#define DO_NOT_APPEND 0
+
 typedef void Sigfunc(int);
 /* Sigfunc *signal(int, Sigfunc *); */
 typedef RETSIGTYPE (*SIGHANDLERTYPE) (int);
@@ -32,12 +35,17 @@ swgp_stdioPump(int stdoutfd,
 		int * waitret, 
 		int * statusp, 
 		int * cancel,
-		unsigned long int * statbytes);
-/* int swgp_pump_line(int ofd, int ifd); */
-int swgp_read_line(int fd, STROB * buf);
+		uintmax_t * statbytes);
+int swgp_write_as_echo_line(int fd, char * buf);
+int swgp_read_line(int fd, STROB * buf, int do_append);
 int swgp_close_all_fd(int start);
 int swgpReadFdNonblock(char * pipe_buf, int efd_from, int * len);
 int swgpReadLine(STROB * buf, int fd_from, int * readReturn);
 void swgp_check_fds(void);
 
+/*
+ssize_t swgp_eread(int fd, void *, size_t);
+ssize_t swgp_ewrite(int fd, void *, size_t);
+*/
+
 #endif
