@@ -329,6 +329,7 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 	taru = taru_create();
 	SWLIB_ASSERT(taru != NULL);
 
+	E_DEBUG("");
 	ret = taru_process_copy_out(taru, ifd, mem_fd, NULL/*defer*/, NULL, arf_ustar, -1, -1, &len, NULL);
 	if (ret < 0) {
 		taru_delete(taru);
@@ -337,11 +338,13 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 		return -1;
 	}
 	
+	E_DEBUG("");
 	ret = uxfio_lseek(mem_fd, (off_t)0, SEEK_SET);
 	if (ret != 0) {
 		taru_delete(taru); uxfio_close(mem_fd);	return -2;
 	}
 
+	E_DEBUG("");
 	/* Check for empty i.e. end-of-archive */
 	nullarchive = 0;
 	zerobuf = (char*)malloc(TARRECORDSIZE);
@@ -356,9 +359,11 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 			nullarchive = 1;	
 		}
 	}
+	E_DEBUG("");
 	free(zerobuf);
 	free(readbuf);
 
+	E_DEBUG("");
 	ret = uxfio_lseek(mem_fd, (off_t)0, SEEK_SET);
 	if (ret != 0) {
 		taru_delete(taru); uxfio_close(mem_fd);	return -2;
@@ -367,9 +372,11 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 	xformat = xformat_open(-1, -1, arf_ustar);
 	SWLIB_ASSERT(xformat != NULL);
 
+	E_DEBUG("");
 	if (nullarchive == 0) {
 		ret = xformat_open_archive_by_fd(xformat, mem_fd, UINFILE_DETECT_NATIVE, 0);
 		if (ret != 0) {
+			E_DEBUG("error, returning -3");
 			uxfio_close(mem_fd);
 			taru_delete(taru);
 			xformat_close(xformat);	
@@ -377,6 +384,7 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 		}
 	}
 
+	E_DEBUG("");
 	swicat_e->xformatM = xformat;
 	swicat_e->taruM = taru;
 	swicat_e->taru_close_on_e_deleteM = 1;
@@ -385,6 +393,7 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 	swicat_e->entry_fdM = mem_fd;
 	swicat_e->entry_prefixM = NULL;
 
+	E_DEBUG("");
 	/* sanity check */
 	ret = uxfio_lseek(mem_fd, (off_t)0, SEEK_END);
 	if (ret < 0) {
@@ -396,8 +405,10 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 		return -5;
 	}
 	
+	E_DEBUG("");
 	uxfio_lseek(mem_fd, (off_t)0, SEEK_SET);
 
+	E_DEBUG("");
 	if (nullarchive == 0) {
 		ret = init_catalog_entry(swicat_e, swicat_e->xformatM->swvarfsM, (char*)NULL);
 		if (ret != 0) {
@@ -408,8 +419,10 @@ swicat_e_open_entry_tarball(SWICAT_E * swicat_e, int ifd)
 	} else {
 		retval = SWICAT_RETVAL_NULLARCHIVE;
 	}	
+	E_DEBUG("");
 	uxfio_lseek(mem_fd, (off_t)0, SEEK_SET);
 
+	E_DEBUG2("retval = %d", retval);
 	return retval;
 }
 
@@ -908,6 +921,9 @@ swicat_e_open_swi(SWICAT_E * e)
 	E_DEBUG2("LOWEST LEAVING AA swicat_e_open_swi FD=%d", show_nopen());
 
 	installed_header = swicat_e_isf_parse(e, &isf_status, (AHS*)NULL);
+	if (!installed_header)
+		return NULL;
+
 	initialize_file_conflicts_fd(swi, installed_header);
 
 	return swi;
