@@ -387,11 +387,13 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 	STROB * enddesc;
 	STROB * ubuf;
 	STROB * synct_eof_buf;
+	STROB * synct_eof_buf2;
 	uintmax_t blocks;
 	
 	ubuf = strob_open(32);
 	enddesc = strob_open(32);
 	synct_eof_buf = strob_open(32);
+	synct_eof_buf2 = strob_open(32);
 	blocks = (int)(size / 512);
 	if (size % 512) {
 		/*
@@ -427,7 +429,7 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		"(\n"
 		"(\n"
 		);
-		swlib_append_synct_eof(synct_eof_buf);
+		swlib_append_synct_eof(synct_eof_buf2);
 	}
 
 	strob_sprintf(enddesc, 0, "%s: " SWEVENT_STATUS_PFX "$sw_retval", task_desc);
@@ -448,6 +450,7 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		"		0)\n"
 		" 			;;\n"
 		"		*)\n"
+		"			%s\n"	
 		"			dd count=%s of=/dev/null 2>/dev/null\n"
 		"			%s\n"	
 		"			%s\n"
@@ -471,8 +474,9 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		TEVENT(2, -1, SWI_TASK_BEGINS, task_desc),
 		dir,
 		verbosestring,
-		ablocks,
 		strob_str(synct_eof_buf),
+		ablocks,
+		strob_str(synct_eof_buf2),
 		TEVENT(2, -1, SW_INTERNAL_ERROR, "No such directory or no access: $swxdir"),
 		task_script,
 		swlib_utilname_get(),
@@ -481,6 +485,7 @@ print_task_script(SWICOL * swicol, STROB * command, uintmax_t size, char * dir,
 		);
 
 	strob_close(synct_eof_buf);
+	strob_close(synct_eof_buf2);
 	strob_close(ubuf);
 	strob_close(enddesc);
 	return 0;
@@ -1004,11 +1009,14 @@ swicol_send_loop_trailer(SWICOL * swicol, int fd)
 {
 	int ret;
 	char * send = SWICOL_TRAILER "\n";
+	E_DEBUG("");
 	ret = atomicio((ssize_t (*)(int, void *, size_t))write,
 			fd, send, strlen(send));
 	if (ret == (int)strlen(send)) {
+		E_DEBUG("OK");
 		return 0;
 	} else {
+		E_DEBUG("error");
 		return -1;
 	}
 }
