@@ -162,16 +162,13 @@ typedef struct {
 	unsigned char * bufM;
 	unsigned char * tailM;
 	char * trailer_startM;
-	int buf_lenM;
 	int countM;
-	int firstM;
-	int doneM;
-	int done_posM;
-	int remainsM;
+	/* int firstM; */
+	/* int remainsM; */
         char * mtM;   /* TRAILER string */
-        char * mtpM;  /* position in trailer string */
-        int mt_nullsM;  /* Number of NULs interspersed trailer string */
-	int mt_spanM;  /* block span of trailer string */
+        /* char * mtpM; */  /* position in trailer string */
+        /* int mt_nullsM; */ /* Number of NULs interspersed trailer string */
+	/* int mt_spanM; */  /* block span of trailer string */
 } SYNCT;
 
 /* void 		* swlib_realloc(void * ptr, size_t newsize, size_t oldsize); */
@@ -242,6 +239,7 @@ char * 		swlib_dirname(STROB * dest, char * source);
 char * 		swlib_basename(STROB * dest, char * source);
 int		swlib_kill_all_pids(pid_t * pid, int num, int signo, int debug);
 int 		swlib_wait_on_all_pids(pid_t * pid, int num, int * status, int flags, int debug);
+int 		swlib_wait_on_all_pids_with_timeout(pid_t * pid, int num, int * status, int flags, int debug, int tm);
 int 		swlib_update_pid_status(pid_t keypid, int value, pid_t * pid, int * status, int len);
 int		swlib_sha1(int uxfio_fd, char *digest);
 int		sha_stream (int ifd, void *resblock);
