@@ -598,7 +598,7 @@ shls_bashin2() {
 	ih_line=""
 	ihnb=0
 	ihpl=""
-	while true
+	while :
 	do
 		ih_line=`dd count=1 bs=512 2>/dev/null`
 		case "$ih_line" in
@@ -623,7 +623,7 @@ shls_bashin2() {
 
 	# Now read 1 byte at a time until the SWI_TASK is found, it should be the first 'S'
 	ih_line=""
-	while true
+	while :
 	do
 		ih_line=`dd count=1 bs=1 2>/dev/null`
 		case "$ih_line" in
@@ -2134,8 +2134,9 @@ shls_looper_payload() {
 
 shls_looper() {
 	xr_sw_retval=$1
-	while test "$xr_sw_retval" -eq 0 && read line 
+	while test "$xr_sw_retval" -eq 0 </dev/null
 	do
+		read line
 		case "$line" in
 			"TRAILER!!!")
 				break;
