@@ -1,6 +1,7 @@
 # ver_compare.sh
 #
 
+
 swanlib_ret_ver()
 {
 	rem="$1"
@@ -192,6 +193,10 @@ ver_compare()
 	# 2 if old < (older) than new
 }
 
+# This script requires a pre 2007-04-25 version of shell_lib.sh
+echo "This script requires a pre 2007-04-25 version of shell_lib.sh" 1>&2
+exit 1
+
 arg1="$1"
 arg2="$2"
 
