@@ -149,6 +149,48 @@ need_new_pfiles(SWI * swi)
 	return 0;
 }
 
+int
+swi_audit_all_compatible_products(SWI * swi, SWUTS * target_uts, int *pn_products, int * p_swi_index)
+{
+	SWI_PRODUCT * product;
+	SWHEADER * global_index;
+	SWUTS * product_uts;
+	int product_number;
+	int ret;
+	int n_matches;
+
+	if (p_swi_index) *p_swi_index = -1;
+	if (pn_products) *pn_products = 0;
+	n_matches = 0;
+
+	/* Get the global INDEX access header object */
+	global_index = swi_get_global_index_header(swi);
+	swheader_store_state(global_index, NULL);
+
+	/* Loop over the products */
+	product_number = 0;
+	while ((product=swi_package_get_product(swi->swi_pkgM, product_number++))) {
+
+		/* Now set the offset of the relevant part of the global INDEX file
+		   which is the start of the product definition */
+		if (pn_products) ++(*pn_products);
+		swheader_reset(global_index);
+		swheader_set_current_offset(global_index, product->p_baseM.header_indexM);
+
+		product_uts = swuts_create();
+		swi_get_uts_attributes_from_current(swi, product_uts, global_index);
+		ret = swuts_compare(target_uts, product_uts, 0 /*verbose*/);
+		if (ret == 0) {
+			n_matches++;
+			product->is_compatibleM = SW_TRUE;
+			if (p_swi_index) *p_swi_index = product_number-1;
+		}
+		swuts_delete(product_uts);
+	}
+	swheader_restore_state(global_index, NULL);
+	return n_matches;
+}
+
 void
 swi_set_utility_id(SWI * swi, int swc_u_id)
 {
@@ -579,11 +621,15 @@ swi_parse_file(
 	uxfio_lseek(curfd, (off_t)0, SEEK_SET);
 	
 	ret = sw_yyparse(curfd, ofd, name, 0, SWPARSE_FORM_MKUP_LEN);
+	E_DEBUG("");
 	if (ret) {
+		E_DEBUG("");
 		fprintf(stderr,
 		"%s: error parsing %s\n", swlib_utilname_get(), name);
+		return ret;
 		swi_com_fatal_error( __FILE__, __LINE__);
 	}
+	E_DEBUG("");
 	uxfio_write(ofd, "\x00", 1);
 	base = swi_com_get_fd_mem(ofd, &len);
 	newbase = (char*)malloc(len);
@@ -938,12 +984,14 @@ swi_decode_catalog(SWI * swi)
 				E_DEBUG("");
 				swdef_ret = swi_parse_file(swi, name, 
 							swdeffile_type);
+				E_DEBUG("");
 				if (swdef_ret) {
 					fprintf(stderr, "error parsing %s\n",
 							name);
 					retval = -3;
 					break;
 				}
+				E_DEBUG("");
 				copyret = 0;	
 			} else if (xformat_file_has_data(xformat)) {
 				/*
@@ -990,10 +1038,12 @@ swi_decode_catalog(SWI * swi)
 		E_DEBUG("");
 	}
 
+	E_DEBUG("");
 	if (retval < 0) {
 		return retval;
 	}
 	
+	E_DEBUG("");
 	if (swi->does_have_payloadM < 0 /* unset */) {
 		/* Must not have a payload such as the
 		   catalog.tar file from the installed_software_catalog
@@ -1001,6 +1051,7 @@ swi_decode_catalog(SWI * swi)
 		swi->does_have_payloadM = 0;
 	}
 
+	E_DEBUG("");
 	/* sanity check */
 	if (catalog_start_offset < 0) {
 		catalog_start_offset = 0;
@@ -1008,6 +1059,7 @@ swi_decode_catalog(SWI * swi)
 			__FILE__, __LINE__);
 	}
 
+	E_DEBUG("");
 	swi->swi_pkgM->catalog_lengthM = 
 		catalog_end_offset - catalog_start_offset; 
 
@@ -1031,13 +1083,17 @@ swi_decode_catalog(SWI * swi)
 	E_DEBUG("");
 
 	swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_set_verbose_level, (void*)(&(swi->verboseM)));
+	E_DEBUG("");
 	swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_update, NULL);
+	E_DEBUG("");
 	ret = swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_generate_swverid, NULL);
 	if (ret) {
 		if (retval == 0) retval = -1;
 	}
+	E_DEBUG("");
 	swi->swi_pkgM->is_minimal_layoutM = swpath_get_is_minimal_layout(swpath);
 	strob_close(tmp);
+	E_DEBUG("");
 	return retval;
 }
 
@@ -1309,22 +1365,27 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	 * Decode the catalog section.
 	 */
 	ret = swi_decode_catalog(swi);
+	E_DEBUG("");
 
 	/*
 	 * Set the auto disable of the memory cache.
 	 * This will turn off memory cache as soon as the
 	 * file advances beyond the previous farthest point
 	 */
+	E_DEBUG("");
 	swvarfs_uxfio_fcntl(swvarfs, UXFIO_F_ARM_AUTO_DISABLE, 1);
+	E_DEBUG("");
 
 	/*
 	 * Now seek back to the beginning of the package.
 	 */
+	E_DEBUG("");
 	if (uxfio_lseek(ifd, 0, SEEK_SET) != 0) {
 		fprintf(stderr, "uxfio_lseek error: %s : %d\n", __FILE__, __LINE__);
 		exit(1);
 	}
 
+	E_DEBUG("");
         swpath_reset(swpath);
 	if (ret) {
 		/*
@@ -1337,48 +1398,47 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	} else {
 		retval = 0;
 	}
+	E_DEBUG("");
 	return retval;
 }
 
 int
-swi_find_compatible_product(SWI * swi, SWUTS * target_uts, int *pn_products, int * p_swi_index)
+swi_find_compatible_product(SWI * swi, SWUTS * target_uts, int disallow_incompat)
 {
 	SWI_PRODUCT * product;
 	SWHEADER * global_index;
 	SWUTS * product_uts;
-	int product_number;
+	int check_found;
+	int retval;
 	int ret;
+	int product_number;
 	int n_matches;
+	int n_products;
 
-	if (pn_products) *pn_products = 0;
-	n_matches = 0;
+	n_matches = swi_audit_all_compatible_products(swi, target_uts, &n_products, (int*)NULL);
 
-	/* Get the global INDEX access header object */
-	global_index = swi_get_global_index_header(swi);
-	swheader_store_state(global_index, NULL);
+	if (disallow_incompat == 0 &&
+	    n_matches == 0 &&
+	    n_products == 1)
+		return 0;  /* index of first product */
 
-	/* Loop over the products */
+	if (n_matches == 1 && n_products == 1)
+		return 0;  /* index of first product */
+
+	check_found = 0;
 	product_number = 0;
-	while ((product=swi_package_get_product(swi->swi_pkgM, product_number++))) {
-
-		/* Now set the offset of the relevant part of the global INDEX file
-		   which is the start of the product definition */
-		if (pn_products) ++(*pn_products);
-		swheader_reset(global_index);
-		swheader_set_current_offset(global_index, product->p_baseM.header_indexM);
-
-		product_uts = swuts_create();
-		swi_get_uts_attributes_from_current(swi, product_uts, global_index);
-		ret = swuts_compare(target_uts, product_uts, 0 /*verbose*/);
-		if (ret == 0) {
-			n_matches++;
-			product->is_compatibleM = SW_TRUE;
-			if (p_swi_index) *p_swi_index = product_number-1;
+	while ((product=swi_package_get_product(swi->swi_pkgM, product_number))) {
+		if (product->is_compatibleM == SW_TRUE) {
+			check_found = 1;
+			break;
 		}
-		swuts_delete(product_uts);
+		product_number++;
 	}
-	swheader_restore_state(global_index, NULL);
-	return n_matches;
+
+	if (product_number >= n_products)
+		return -1;
+
+	return product_number;
 }
 
 SWHEADER *
@@ -1544,49 +1604,13 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 	}
 
 	E_DEBUG("");
-	n_compat = swi_find_compatible_product(swi, swuts, &n_products, NULL);
+	product_number = swi_find_compatible_product(swi, swuts, disallow_incompatible);
 
-	/* Now check for non-root "/" target and for packages that only have
-	   one product, claim it is compatible */
-
-	if (
-		strcmp(swi->swi_pkgM->target_pathM, SW_ROOT_DIR) != 0 &&
-		n_products == 1 &&
-		n_compat == 0 &&
-		disallow_incompatible == 0 &&
-		1
-	) {
-		/* this is useful for using swremove on an alernate root */
-		product = swi_package_get_product(swi->swi_pkgM, SWI_PRODUCT_0);
-		product->is_compatibleM = SW_TRUE;
-		swutil_doif_writef(swi->verboseM, SWC_VERBOSE_1, NULL, STDERR_FILENO,
-			"Warning: no compatible found, continuing with first and only product\n");
-		n_compat = 1;
-	}
-
-	if (n_compat  <= 0) {
+	if (product_number < 0) {
 		/* SWLIB_INTERNAL("no compatible product found in entry"); */
 		SWLIB_WARN("no compatible product found in entry");
-		;
-	} else if (n_compat  > 1) {
-		SWLIB_WARN("more than one compatible product found");
-		;
-	}
-	E_DEBUG("");
-
-	check_found = 0;
-	product_number = 0;
-	while ((product=swi_package_get_product(swi->swi_pkgM, product_number))) {
-		if (product->is_compatibleM == SW_TRUE) {
-			check_found = 1;
-			break;
-		}
-		product_number++;
-	}
-
-	if (check_found != 1) {
-		SWLIB_ERROR("");
 		return NULL;
+		;
 	}
 	E_DEBUG("");
 
