@@ -233,7 +233,8 @@ int swi_do_decode(SWI * swi, SWLOG * swutil,
 	struct sw_logspec * g_logspec,
 	int uinfile_open_flags);
 
-int swi_find_compatible_product(SWI * swi, SWUTS * target_uts, int * num_products, int * swi_index);
+int swi_audit_all_compatible_products(SWI * swi, SWUTS * target_uts, int *pn_products, int * p_swi_index);
+int swi_find_compatible_product(SWI * swi, SWUTS * target_uts, int);
 SWHEADER * swi_get_global_index_header(SWI * swi);
 SWHEADER * swi_get_fileset_info_header(SWI * swi, int product_index, int fileset_index);
 SWI_FILELIST * swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * location);
