@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 #include "uxfio.h"
@@ -98,13 +98,14 @@ uxfio_dump_string_recursive(int uxfio_fildes, UXFIO * uxfio,  char * prefix, cha
 
 	p += uxfio_dump_string_recursive(uxfio->uxfdM, NULL,  prebuf,  &p);
 
-	p += snprintf(p, 270, "%s can_seekM        = [%d]\n", prefix,  uxfio->uxfd_can_seekM);
+	p += snprintf(p, 270, "%s uxfd_can_seekM   = [%d]\n", prefix,  uxfio->uxfd_can_seekM);
 	p += snprintf(p, 270, "%s posM             = [%d]\n", prefix,  uxfio->posM);
 	p += snprintf(p, 270, "%s startM           = [%d]\n", prefix,  uxfio->startM);
 	p += snprintf(p, 270, "%s endM             = [%d]\n", prefix,  uxfio->endM);
 	p += snprintf(p, 270, "%s lenM             = [%d]\n", prefix,  uxfio->lenM);
 	p += snprintf(p, 270, "%s errorM           = [%d]\n", prefix,  uxfio->errorM);
 	p += snprintf(p, 270, "%s current_offsetM  = [%d]\n", prefix,  uxfio->current_offsetM);
+	p += snprintf(p, 270, "%s virtual_offsetM  = [%d]\n", prefix,  uxfio->virtual_offsetM);
 	p += snprintf(p, 270, "%s bytesreadM       = [%d]\n", prefix,  uxfio->bytesreadM);
 	p += snprintf(p, 270, "%s buffd            = [%d]\n", prefix,  uxfio->buffdM);
 	p += snprintf(p, 270, "%s buffer active    = [%d]\n", prefix,  uxfio->buffer_activeM);
@@ -112,6 +113,10 @@ uxfio_dump_string_recursive(int uxfio_fildes, UXFIO * uxfio,  char * prefix, cha
 	p += snprintf(p, 270, "%s buffilename      = [%s]\n", prefix,  uxfio->buffilenameM);
 	p += snprintf(p, 270, "%s use count        = [%d]\n", prefix,  uxfio->use_countM);
 	p += snprintf(p, 270, "%s offset eof       = [%d]\n", prefix,  (int)(uxfio->offset_eofM));
+	p += snprintf(p, 270, "%s offset_eofM         = [%d]\n", prefix, (int)(uxfio->offset_eofM));
+	p += snprintf(p, 270, "%s offset_eof_savedM   = [%d]\n", prefix, (int)(uxfio->offset_eof_savedM));
+	p += snprintf(p, 270, "%s offset_bofM         = [%d]\n", prefix, (int)(uxfio->offset_bofM));
+	p += snprintf(p, 270, "%s v_endM              = [%d]\n", prefix, (int)(uxfio->v_endM));
 
 	free(prebuf);
 	return  (int)(p - *a);
@@ -193,13 +198,18 @@ uxfio_dump_string_internal(int uxfio_fildes, UXFIO * uxfio_object)
 	p += snprintf(p, 50, "lenM             : %d\n", uxfio->lenM);
 	p += snprintf(p, 50, "errorM           : %d\n", uxfio->errorM);
 	p += snprintf(p, 50, "current_offsetM   : %d\n", uxfio->current_offsetM);
+	p += snprintf(p, 50, "virtual_offsetM   : %d\n", uxfio->virtual_offsetM);
 	p += snprintf(p, 50, "bytesreadM        : %d\n", uxfio->bytesreadM);
 	p += snprintf(p, 50, "buffd             : %d\n", uxfio->buffdM);
 	p += snprintf(p, 50, "buffer_activeM     : %d\n", uxfio->buffer_activeM);
-	p += snprintf(p, 50, "buffertypeM       : %d\n", uxfio->buffertypeM);
-	p += snprintf(p, 50, "buffilename          : %s\n", uxfio->buffilenameM);
+	p += snprintf(p, 50, "buffertypeM        : %d\n", uxfio->buffertypeM);
+	p += snprintf(p, 50, "buffilename        : %s\n", uxfio->buffilenameM);
 	p += snprintf(p, 50, "use_countM         : %d\n", uxfio->use_countM);
 	p += snprintf(p, 50, "offset_eofM        : %d\n", (int)(uxfio->offset_eofM));
+	p += snprintf(p, 50, "offset_eof_savedM  : %d\n", (int)(uxfio->offset_eof_savedM));
+	p += snprintf(p, 50, "offset_bofM        : %d\n", (int)(uxfio->offset_bofM));
+	p += snprintf(p, 50, "v_endM             : %d\n", (int)(uxfio->v_endM));
+	
 
 	return a;
 }
